Installing Products.GenericSetup — Products.GenericSetup 2.0b6.dev0 documentation

# Installing `Products.GenericSetup`

## Installation via easy_install

GenericSetup can be installed using the `setuptools` utility, easy_install, into the `site-packages` directory of your Python installation:

    $ bin/easy_install Products.GenericSetup

## Installation via `zc.buildout`

TBD

## Manual Installation

To install this package manually, without using `setuptools`, simply untar the package file downloaded from the PyPI site and look for the folder named `GenericSetup` underneath the `Products` folder at the root of the extracted tarball. Copy or link this `GenericSetup` folder into the `Products` folder of your Zope instance and restart Zope.